# -*- coding: utf-8 -*-
# Description:
# Test for PaloAlto Traffic
#
# Authors:
# Benoît Allard <benoit.allard@greenbone.net>
#
# Copyright:
# Copyright (C) 2015 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest

import xml.etree.ElementTree as ET

from ospd_paloalto.paloalto import Threat

class testThreat(unittest.TestCase):

    def testParsing(self):
        threat = Threat(ET.fromstring("""
      <entry>
        <threatid>HTTP WWW-Authentication Failed</threatid>
        <tid>31708</tid>
        <severity>informational</severity>
        <dst>192.168.181.122</dst>
        <resolved-dst>192.168.181.122</resolved-dst>
        <dport>65530</dport>
        <src>127.0.0.31</src>
        <resolved-src>127.0.0.31</resolved-src>
        <sport>0</sport>
        <proto>tcp</proto>
        <action>block-ip</action>
        <repeatcnt>51</repeatcnt>
      </entry>
            """))
        self.assertEquals(threat.name, 'HTTP WWW-Authentication Failed')
        self.assertEquals(threat.id, 31708)
        self.assertEquals(threat.severity, 'informational')
        self.assertEquals(threat.action, 'block-ip')
        self.assertEquals(threat.destination, ('192.168.181.122', 65530))
        self.assertEquals(threat.protocol, 'tcp')

    def testKeying(self):
        threat1 = Threat(ET.fromstring("<entry><tid>5897</tid><dport>5</dport><proto>ulmp</proto></entry>"))
        threat2 = Threat(ET.fromstring("<entry><tid>5897</tid><dport>5</dport><proto>ulmp</proto></entry>"))
        d = {}
        d[threat1] = 5
        self.assertTrue(threat1 == threat2)
        self.assertEquals(threat1, threat2)
        self.assertFalse(threat1 is threat2)
        self.assertEquals(hash(threat1), hash(threat2))
        self.assertTrue(threat2 in d)
        self.assertEquals(d[threat2], 5)
        
