# -*- coding: utf-8 -*-
# Description:
# Test for getting ports from PaloAlto traffic data.
#
# Authors:
# Benoît Allard <benoit.allard@greenbone.net>
#
# Copyright:
# Copyright (C) 2015 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest

from ospd_paloalto import wrapper

class MyTraffic(object):
    def __init__(self, proto, dport, app):
        self.protocol = proto
        self.dst = ('a.b.c.d', dport)
        self.app = (app, 0)

class MyClient(object):
    def __init__(self, ad, user, pw):
        pass

    def get_traffic(self, target, period, nreq):
        for i in range(min(nreq, 4875)):
            yield MyTraffic('tcp', nreq, 'incomplete')


wrapper.PANOSClient = MyClient

class Testgetports(unittest.TestCase):

    def testgetports(self):

        udp, tcp = wrapper.getPorts('a.b.c.d', 'e.f.g.h', 'a', 'b', 'last-5-mins')
        self.assertEquals(udp.keys(), [])
        self.assertEquals(tcp.keys(), [1000, 2000, 4000, 8000])
        self.assertEquals(tcp[1000], set(['incomplete']))

class TestResultForPort(unittest.TestCase):
    def testTCP(self):
        d = wrapper.getResultForPort('45', set(['unknown-tcp', 'insufficient-data', 'smtp', 'non-syn-tcp', 'incomplete']), 'last-2-hrs', 'tcp')
        self.assertEquals(d.keys(), ['qod', 'port', 'value'])
        self.assertEquals(d['qod'], 80)
        self.assertEquals(d['port'], '45/tcp')
        self.assertEquals(d['value'], 'Traffic analysis of last-2-hrs showed replies from a service at TCP port 45.\n\nThe following protocol(s) have been seen on that port: unknown-tcp, smtp, non-syn-tcp')
